"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.assetsPath = exports.ConnectionListItem = exports.SparqlNotebookConnections = void 0;
const vscode = require("vscode");
const path = require("path");
const extension_1 = require("./extension");
class SparqlNotebookConnections {
    constructor(context) {
        this.context = context;
        this._onDidChangeTreeData = new vscode.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
        this.refresh();
        this.activeConn = null;
    }
    refresh() {
        this._onDidChangeTreeData.fire();
    }
    getTreeItem(element) {
        return element;
    }
    setActive(connName) {
        this.activeConn = connName;
        this.refresh();
    }
    getChildren(element) {
        if (element) {
            return Promise.resolve([
                new vscode.TreeItem(`EndPointURL: ${element.config.endpointURL}`, vscode.TreeItemCollapsibleState.None),
                new vscode.TreeItem(`User: ${element.config.user}`, vscode.TreeItemCollapsibleState.None),
            ]);
        }
        const connections = this.context.globalState.get(extension_1.storageKey) ?? [];
        return Promise.resolve(connections.map((config) => new ConnectionListItem(config, config.name === this.activeConn, vscode.TreeItemCollapsibleState.Expanded)));
    }
}
exports.SparqlNotebookConnections = SparqlNotebookConnections;
class ConnectionListItem extends vscode.TreeItem {
    constructor(config, isActive, collapsibleState, command) {
        super(config.name, collapsibleState);
        this.config = config;
        this.isActive = isActive;
        this.collapsibleState = collapsibleState;
        this.command = command;
        if (isActive) {
            this.iconPath = {
                dark: path.join(exports.assetsPath, "dark", "dbconnection.svg"),
                light: path.join(exports.assetsPath, "light", "dbconnection.svg"),
            };
            this.description = "Connected";
        }
        else {
            this.iconPath = {
                dark: path.join(exports.assetsPath, "dark", "database.svg"),
                light: path.join(exports.assetsPath, "light", "database.svg"),
            };
            this.description = "Inactive";
        }
        this.contextValue = "database";
    }
}
exports.ConnectionListItem = ConnectionListItem;
exports.assetsPath = path.join(__filename, "..", "..", "..", "assets");
//# sourceMappingURL=db-connection.js.map